@@ -17,7 +17,7 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 from abc import ABCMeta, abstractproperty
 from collections import namedtuple
-from six.collections_abc import MutableMapping, MutableSequence, Mapping, Sequence
+from six.moves.collections_abc import MutableMapping, MutableSequence, Mapping, Sequence
 import fnmatch
 import keyword
 import re
